app

package
v0.1.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 27, 2024 License: BSD-2-Clause Imports: 14 Imported by: 0

README

ev7ab / app

Package app provides basic usage of lab package with CUI.

Documentation

go.dev reference

Usage

cfgFile := flag.String("config", "./app.config.json", "path to app config file")
flag.Parse()
app.Run(&producer{}, *cfgFile)

Examples dir contains several solutions for different typical tasks.

Documentation

Overview

Package app provides basic usage of lab package with CUI.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Run

func Run(prod lab.Producer, appConfigFile string)

Run used for starting application with *Producer and configuration file path.

Types

This section is empty.

Jump to